module.exports = defineTest({
	description: 'function-mutations do not have effects',
	options: { output: { name: 'bundle' } }
});
